@@ -35,7 +35,7 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 struct RecursiveDirModelPrivate {
-    KDirLister *mDirLister;
+    KDirLister *mDirLister = nullptr;
 
     int rowForUrl(const QUrl &url) const
     {
@@ -90,11 +90,7 @@ RecursiveDirModel::RecursiveDirModel(QObject *parent)
     connect(d->mDirLister, QOverload<>::of(&KDirLister::completed), this, &RecursiveDirModel::completed);
     connect(d->mDirLister, QOverload<>::of(&KDirLister::clear), this, &RecursiveDirModel::slotCleared);
 
-#if KIO_VERSION < QT_VERSION_CHECK(5, 79, 0)
-    connect(d->mDirLister, QOverload<const QUrl &>::of(&KDirLister::clear), this, &RecursiveDirModel::slotDirCleared);
-#else
     connect(d->mDirLister, &KDirLister::clearDir, this, &RecursiveDirModel::slotDirCleared);
-#endif
 }
 
 RecursiveDirModel::~RecursiveDirModel()
@@ -127,12 +123,12 @@ int RecursiveDirModel::rowCount(const QModelIndex &parent) const
 QVariant RecursiveDirModel::data(const QModelIndex &index, int role) const
 {
     if (index.parent().isValid()) {
-        return QVariant();
+        return {};
     }
     KFileItem item = d->list().value(index.row());
     if (item.isNull()) {
         qCWarning(GWENVIEW_LIB_LOG) << "Invalid row" << index.row();
-        return QVariant();
+        return {};
     }
     switch (role) {
     case Qt::DisplayRole:
@@ -145,7 +141,7 @@ QVariant RecursiveDirModel::data(const QModelIndex &index, int role) const
         qCWarning(GWENVIEW_LIB_LOG) << "Unhandled role" << role;
         break;
     }
-    return QVariant();
+    return {};
 }
 
 void RecursiveDirModel::slotItemsAdded(const QUrl &, const KFileItemList &newList)
